@@ -15,6 +15,7 @@
 
 import uuid
 
+import openstack.exceptions
 import testtools
 from testtools import matchers
 
@@ -32,7 +33,6 @@ class TestDomains(base.RequestsMockTestCase):
             append=append, base_url_append=base_url_append)
 
     def test_list_domains(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data()
         self.register_uris([
             dict(method='GET', uri=self.get_mock_url(), status_code=200,
@@ -46,7 +46,6 @@ class TestDomains(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_get_domain(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data()
         self.register_uris([
             dict(method='GET',
@@ -59,7 +58,6 @@ class TestDomains(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_get_domain_with_name_or_id(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data()
         response = {'domains': [domain_data.json_response['domain']]}
         self.register_uris([
@@ -79,17 +77,12 @@ class TestDomains(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_create_domain(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data(description=uuid.uuid4().hex,
                                             enabled=True)
         self.register_uris([
             dict(method='POST', uri=self.get_mock_url(), status_code=200,
                  json=domain_data.json_response,
-                 validate=dict(json=domain_data.json_request)),
-            dict(method='GET',
-                 uri=self.get_mock_url(append=[domain_data.domain_id]),
-                 status_code=200,
-                 json=domain_data.json_request)])
+                 validate=dict(json=domain_data.json_request))])
         domain = self.op_cloud.create_domain(
             domain_data.domain_name, domain_data.description)
         self.assertThat(domain.id, matchers.Equals(domain_data.domain_id))
@@ -99,33 +92,33 @@ class TestDomains(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_create_domain_exception(self):
-        self._add_discovery_uri_call()
+        domain_data = self._get_domain_data(domain_name='domain_name',
+                                            enabled=True)
         with testtools.ExpectedException(
-            shade.OpenStackCloudException,
+            shade.OpenStackCloudBadRequest,
             "Failed to create domain domain_name"
         ):
             self.register_uris([
-                dict(method='POST', uri=self.get_mock_url(), status_code=409)])
+                dict(method='POST', uri=self.get_mock_url(), status_code=400,
+                     json=domain_data.json_response,
+                     validate=dict(json=domain_data.json_request))])
             self.op_cloud.create_domain('domain_name')
         self.assert_calls()
 
     def test_delete_domain(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data()
         new_resp = domain_data.json_response.copy()
         new_resp['domain']['enabled'] = False
         domain_resource_uri = self.get_mock_url(append=[domain_data.domain_id])
         self.register_uris([
             dict(method='PATCH', uri=domain_resource_uri, status_code=200,
-                 json=new_resp, validate={'domain': {'enabled': False}}),
-            dict(method='GET', uri=domain_resource_uri, status_code=200,
-                 json=new_resp),
+                 json=new_resp,
+                 validate=dict(json={'domain': {'enabled': False}})),
             dict(method='DELETE', uri=domain_resource_uri, status_code=204)])
         self.op_cloud.delete_domain(domain_data.domain_id)
         self.assert_calls()
 
     def test_delete_domain_name_or_id(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data()
         new_resp = domain_data.json_response.copy()
         new_resp['domain']['enabled'] = False
@@ -135,9 +128,8 @@ class TestDomains(base.RequestsMockTestCase):
             dict(method='GET', uri=self.get_mock_url(), status_code=200,
                  json={'domains': [domain_data.json_response['domain']]}),
             dict(method='PATCH', uri=domain_resource_uri, status_code=200,
-                 json=new_resp, validate={'domain': {'enabled': False}}),
-            dict(method='GET', uri=domain_resource_uri, status_code=200,
-                 json=new_resp),
+                 json=new_resp,
+                 validate=dict(json={'domain': {'enabled': False}})),
             dict(method='DELETE', uri=domain_resource_uri, status_code=204)])
         self.op_cloud.delete_domain(name_or_id=domain_data.domain_id)
         self.assert_calls()
@@ -148,35 +140,30 @@ class TestDomains(base.RequestsMockTestCase):
         # to update domain even though it is called via delete_domain. This
         # should be fixed in shade to catch either a failure on PATCH,
         # subsequent GET, or DELETE call(s).
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data()
         new_resp = domain_data.json_response.copy()
         new_resp['domain']['enabled'] = False
         domain_resource_uri = self.get_mock_url(append=[domain_data.domain_id])
         self.register_uris([
             dict(method='PATCH', uri=domain_resource_uri, status_code=200,
-                 json=new_resp, validate={'domain': {'enabled': False}}),
-            dict(method='GET', uri=domain_resource_uri, status_code=200,
-                 json=new_resp),
+                 json=new_resp,
+                 validate=dict(json={'domain': {'enabled': False}})),
             dict(method='DELETE', uri=domain_resource_uri, status_code=404)])
         with testtools.ExpectedException(
-            shade.OpenStackCloudException,
+            shade.OpenStackCloudURINotFound,
             "Failed to delete domain %s" % domain_data.domain_id
         ):
             self.op_cloud.delete_domain(domain_data.domain_id)
         self.assert_calls()
 
     def test_update_domain(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data(
             description=self.getUniqueString('domainDesc'))
         domain_resource_uri = self.get_mock_url(append=[domain_data.domain_id])
         self.register_uris([
             dict(method='PATCH', uri=domain_resource_uri, status_code=200,
                  json=domain_data.json_response,
-                 validate=dict(json=domain_data.json_request)),
-            dict(method='GET', uri=domain_resource_uri, status_code=200,
-                 json=domain_data.json_response)])
+                 validate=dict(json=domain_data.json_request))])
         domain = self.op_cloud.update_domain(
             domain_data.domain_id,
             name=domain_data.domain_name,
@@ -188,7 +175,6 @@ class TestDomains(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_update_domain_name_or_id(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data(
             description=self.getUniqueString('domainDesc'))
         domain_resource_uri = self.get_mock_url(append=[domain_data.domain_id])
@@ -197,9 +183,7 @@ class TestDomains(base.RequestsMockTestCase):
                  json={'domains': [domain_data.json_response['domain']]}),
             dict(method='PATCH', uri=domain_resource_uri, status_code=200,
                  json=domain_data.json_response,
-                 validate=dict(json=domain_data.json_request)),
-            dict(method='GET', uri=domain_resource_uri, status_code=200,
-                 json=domain_data.json_response)])
+                 validate=dict(json=domain_data.json_request))])
         domain = self.op_cloud.update_domain(
             name_or_id=domain_data.domain_id,
             name=domain_data.domain_name,
@@ -211,15 +195,16 @@ class TestDomains(base.RequestsMockTestCase):
         self.assert_calls()
 
     def test_update_domain_exception(self):
-        self._add_discovery_uri_call()
         domain_data = self._get_domain_data(
             description=self.getUniqueString('domainDesc'))
         self.register_uris([
             dict(method='PATCH',
                  uri=self.get_mock_url(append=[domain_data.domain_id]),
-                 status_code=409)])
+                 status_code=409,
+                 json=domain_data.json_response,
+                 validate=dict(json={'domain': {'enabled': False}}))])
         with testtools.ExpectedException(
-            shade.OpenStackCloudException,
+            openstack.exceptions.ConflictException,
             "Error in updating domain %s" % domain_data.domain_id
         ):
             self.op_cloud.delete_domain(domain_data.domain_id)
